@@ -14,6 +14,7 @@ from .defines import (
     DIGIT_STR,
     DUMMY,
     EMAIL,
+    FOREACH,
     INT,
     JSON,
     JSON_BOOL,
@@ -30,7 +31,10 @@ from .defines import (
     UUID,
     Checker,
     CheckerOP,
+    DSVError,
+    ErrorMode,
     not_,
     reset_msg_level,
 )
 from .features import dsv_feature
+from .utils import raise_if
